@@ -213,3 +213,17 @@ class Model:
                                 c = cls.get(**kwg)
                                 break     
                 setattr(self, cl, c)        
+    
+    @classmethod
+    def __meta__(cls):
+        return ('id',)
+    
+    @property
+    def admin_dis(self):
+        tp = self.__meta__()
+        f = []
+        for t in tp:
+            f.append(getattr(self, t))
+        print(f)    
+        return f    
+    
\ No newline at end of file
