@@ -95,29 +95,31 @@ class Request:
         self.server_protocol = environ.get('SERVER_PROTOCOL')
         self.server_software = environ.get('SERVER_SOFTWARE')
 
+        self.set_session_id()
         # auth request's
-        authentication.authenticate(self.http_cookie, self.session)
+        authentication.authenticate(self.session_id, self.session)
 
         self.user = authentication.get_user()
         self.is_authenticated = self.user != authentication.ANONYMOUS 
         self.session_id = authentication.session_id
         self.parse_qs()
-        self.pass_csrf()
-        self.set_session_id()
+        # self.pass_csrf()
         pass
     
     def set_session_id(self):
         found = False
-        for c in self.http_cookie.split(';'):
-            key, value, *_ = c.split('=')
-            # print(2)
-            if key.strip() == 'usersession':
-                self.session_id = value.strip()
-                found = True
-                break
+        if self.http_cookie is not None:
+            
+            for c in self.http_cookie.split(';'):
+                key, value, *_ = c.split('=')
+                # print(2)
+                if key.strip() == 'usersession':
+                    self.session_id = value.strip()
+                    found = True
+                    break
         if found != True:    
             session = ''.join(r.sample(string.ascii_letters, 50))
-
+            self.session_id = session
             self.set_cookie('usersession', session)    
             
     def pass_csrf(self):
@@ -161,6 +163,9 @@ class Request:
                 
     def get_cookie(self):
         return ','.join(self.cookie)  
+    
+    def clear_cookie(self):
+        self.cookie = []
 
     def set_cookie(self, k, v):
         today = datetime.today()
